@@ -8,11 +8,9 @@ from viur.datastore.types import QueryDefinition, DATASTORE_BASE_TYPES, Entity,
 	SkelListRef, KEY_SPECIAL_PROPERTY
 from viur.datastore.transport import runSingleFilter, Get
 from viur.datastore.utils import IsInTransaction
+from viur.datastore.config import conf
 from base64 import urlsafe_b64encode, urlsafe_b64decode
 
-traceQueries = False  #FIXME
-SkeletonInstanceRef = None  #FIXME
-
 
 def _entryMatchesQuery(entry: Entity, singleFilter: dict) -> bool:
 	"""
@@ -499,6 +497,8 @@ class Query(object):
 			another property is provided
 		"""
 		if self.queries is None:
+			if conf["traceQueries"]:
+				logging.debug("Query on %s aborted as being not satisfiable" % self.kind)
 			return []
 
 		if self._fulltextQueryString:
@@ -531,16 +531,6 @@ class Query(object):
 				res = self._mergeMultiQueryResults(res)
 		else:  # We have just one single query
 			res = self._fixKind(self._runSingleFilterQuery(self.queries, limit if limit != -1 else self.queries.limit))
-		if traceQueries:
-			# orders = self.queries.orders
-			filters = self.queries
-			distinctOn = ""  # "" distinct on %s" % str(self._distinct) if self._distinct else ""
-			if self.kind != self.origKind:
-				logging.debug("Queried %s via %s with filter %s and orders %s. Returned %s results" % (
-					self.origKind, self.kind, filters, distinctOn, len(res)))
-			else:
-				logging.debug("Queried %s with filter %s and orders %s. Returned %s results" % (
-					self.kind, filters, distinctOn, len(res)))
 		if res:
 			self._lastEntry = res[-1]
 		return res
@@ -565,10 +555,7 @@ class Query(object):
 			:raises: :exc:`BadQueryError` if an IN filter in combination with a sort order on
 				another property is provided
 		"""
-		global SkeletonInstanceRef
-		if not SkeletonInstanceRef:
-			from viur.core.skeleton import SkeletonInstance as SkeletonInstanceRefOrig
-			SkeletonInstanceRef = SkeletonInstanceRefOrig
+		assert conf["SkeletonInstanceRef"] is not None, "conf['SkeletonInstanceRef'] has not been set!"
 		if self.srcSkel is None:
 			raise NotImplementedError("This query has not been created using skel.all()")
 		# limit = limit if limit != -1 else self._limit
@@ -581,7 +568,7 @@ class Query(object):
 			return None
 		res = SkelListRef(self.srcSkel)
 		for e in dbRes:
-			skelInstance = SkeletonInstanceRef(self.srcSkel.skeletonCls, clonedBoneMap=self.srcSkel.boneMap)
+			skelInstance = conf["SkeletonInstanceRef"](self.srcSkel.skeletonCls, clonedBoneMap=self.srcSkel.boneMap)
 			skelInstance.dbEntity = e
 			res.append(skelInstance)
 		res.getCursor = lambda: self.getCursor()
